#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-DRjKUovO6l159RRdguKqPl
key:                  cookie-0.4.5-DRjKUovO6l159RRdguKqPl
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  1195dde73a16dc4f823d3296f76e5832
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-8.10.5/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-DRjKUovO6l159RRdguKqPl
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    data-default-class-0.1.2.0-9cFfQKP7sucLLfD3ZZyiPI deepseq-1.4.4.0
    text-1.2.4.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

